@@ -1,19 +1,14 @@
+from collections.abc import Callable, Mapping
 from typing import (
     Annotated,
     Any,
     BinaryIO,
-    Callable,
-    Optional,
     TypeVar,
     cast,
 )
 
 from annotated_doc import Doc
-from fastapi._compat import (
-    CoreSchema,
-    GetJsonSchemaHandler,
-    JsonSchemaValue,
-)
+from pydantic import GetJsonSchemaHandler
 from starlette.datastructures import URL as URL  # noqa: F401
 from starlette.datastructures import Address as Address  # noqa: F401
 from starlette.datastructures import FormData as FormData  # noqa: F401
@@ -61,11 +56,11 @@ class UploadFile(StarletteUploadFile):
         BinaryIO,
         Doc("The standard Python file object (non-async)."),
     ]
-    filename: Annotated[Optional[str], Doc("The original file name.")]
-    size: Annotated[Optional[int], Doc("The size of the file in bytes.")]
+    filename: Annotated[str | None, Doc("The original file name.")]
+    size: Annotated[int | None, Doc("The size of the file in bytes.")]
     headers: Annotated[Headers, Doc("The headers of the request.")]
     content_type: Annotated[
-        Optional[str], Doc("The content type of the request, from the headers.")
+        str | None, Doc("The content type of the request, from the headers.")
     ]
 
     async def write(
@@ -142,14 +137,14 @@ class UploadFile(StarletteUploadFile):
 
     @classmethod
     def __get_pydantic_json_schema__(
-        cls, core_schema: CoreSchema, handler: GetJsonSchemaHandler
-    ) -> JsonSchemaValue:
+        cls, core_schema: Mapping[str, Any], handler: GetJsonSchemaHandler
+    ) -> dict[str, Any]:
         return {"type": "string", "format": "binary"}
 
     @classmethod
     def __get_pydantic_core_schema__(
-        cls, source: type[Any], handler: Callable[[Any], CoreSchema]
-    ) -> CoreSchema:
+        cls, source: type[Any], handler: Callable[[Any], Mapping[str, Any]]
+    ) -> Mapping[str, Any]:
         from ._compat.v2 import with_info_plain_validator_function
 
         return with_info_plain_validator_function(cls._validate)
